@@ -1,27 +1,20 @@
-# $Id: ClipZoomTab.pm,v 1.44 2005/06/19 13:58:01 joern Exp $
+# $Id: ClipZoomTab.pm,v 1.6 2001/11/25 12:26:40 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::Project;
-use Locale::TextDomain qw (video.dvdrip);
 
 use Carp;
 use strict;
 
-use Video::DVDRip::GUI::ZoomCalculator;
-
 sub adjust_widgets		{ shift->{adjust_widgets}		}	# href
 sub set_adjust_widgets		{ shift->{adjust_widgets}	= $_[1] }
 
-sub in_adjust_init		{ shift->{in_adjust_init}		}	# href
-sub set_in_adjust_init		{ shift->{in_adjust_init}	= $_[1] }
-
 #------------------------------------------------------------------------
 # Build Adjustments Tab
 #------------------------------------------------------------------------
@@ -37,15 +30,15 @@ sub create_adjust_tab {
 	$vbox->pack_start ( $selected_title, 0, 1, 0);
 
 	my ($label, $entry, $popup_menu, $popup, $item,
-	    $box, $image, $button, $frame, $hbox, $vbutton);
+	    $box, $image, $button, $frame, $hbox);
 
 	# preview images -------------------------------------------------
 
 	my $title = $self->selected_title;
 
-	$frame = Gtk::Frame->new (__"Preview images");
+	$frame = Gtk::Frame->new ("Preview Images");
 	$frame->show;
-	$vbox->pack_start ( $frame, 1, 1, 0);
+	$vbox->pack_start ( $frame, 0, 1, 0);
 
 	$box = Gtk::VBox->new;
 	$box->show;
@@ -57,53 +50,27 @@ sub create_adjust_tab {
 	$hbox->show;
 	$box->pack_start($hbox, 0, 1, 0);
 
-	$label = Gtk::Label->new (__"Grab preview frame #");
+	$label = Gtk::Label->new ("Grab Preview Frame #");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number      => 1,
-		is_min	       => 0,
-		is_max	       => undef,
-		may_fractional => 0,
-		may_empty      => 0,
-		may_negative   => 0,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_usize(80, undef);
 	$entry->show;
 	$hbox->pack_start($entry, 0, 1, 0);
 	$self->adjust_widgets->{preview_frame_nr} = $entry;
 
-	$button = Gtk::Button->new_with_label (__"Grab frame");
+	$button = Gtk::Button->new_with_label ("Grab Frame from ripped VOB");
 	$button->show;
 	$button->signal_connect ("clicked", sub { $self->grab_preview_frame } );
 	$hbox->pack_start($button, 0, 1, 0);
 
-	$button = Gtk::Button->new_with_label (__"Show video from here");
-	$button->show;
-	$button->signal_connect ("clicked", sub { $self->preview_video } );
-	$hbox->pack_start($button, 0, 1, 0);
-	$self->adjust_widgets->{show_video_from_here_button} = $button;
-
-	my $checkbox = Gtk::CheckButton->new(__"Force slow frame grabbing");
-	$checkbox->show;
-	$hbox->pack_start($checkbox, 0, 1, 0);
-
-	$self->adjust_widgets->{force_slow_grabbing} = $checkbox;
-
-	$checkbox->signal_connect("clicked" => sub {
-		my $title = $self->selected_title;
-		return 1 if not $title;
-		$title->set_tc_force_slow_grabbing($_[0]->get_active);
-		1;
-	} );
-
 	# images
 
 	$hbox = Gtk::HBox->new (0, 20);
 	$hbox->set_border_width(5);
 	$hbox->show;
-	$box->pack_start($hbox, 1, 1, 0);
+	$box->pack_start($hbox, 0, 1, 0);
 
 	# Clipping 1
 
@@ -116,12 +83,11 @@ sub create_adjust_tab {
 	$box->pack_start ($frame, 0, 1, 0);
 	
 	$image = Video::DVDRip::GUI::ImageClip->new (
-		gtk_window    => $self->comp('main')->widget,
-		width         => 180,
-		height        => 160,
-		thumbnail     => $self->config('thumbnail_factor'),
-		no_clip       => 1,
-		show_tooltips => $self->config('show_tooltips'),
+		gtk_window => $self->comp('main')->widget,
+		width      => 180,
+		height     => 160,
+		thumbnail  => $self->config('thumbnail_factor'),
+		no_clip    => 1,
 	);
 	$frame->add ($image->widget);
 	$image->widget->signal_connect (
@@ -134,7 +100,7 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{image_clip1} = $image;
 
-	$label = Gtk::Label->new (__"After 1st clipping");
+	$label = Gtk::Label->new ("After 1st Clipping");
 	$label->show;
 	$box->pack_start ($label, 0, 1, 0);
 	$label = Gtk::Label->new ("");
@@ -153,12 +119,11 @@ sub create_adjust_tab {
 	$box->pack_start ($frame, 0, 1, 0);
 	
 	$image = Video::DVDRip::GUI::ImageClip->new (
-		gtk_window    => $self->comp('main')->widget,
-		width         => 180,
-		height        => 160,
-		thumbnail     => $self->config('thumbnail_factor'),
-		no_clip       => 1,
-		show_tooltips => $self->config('show_tooltips'),
+		gtk_window => $self->comp('main')->widget,
+		width      => 180,
+		height     => 160,
+		thumbnail  => $self->config('thumbnail_factor'),
+		no_clip    => 1,
 	);
 	$frame->add ($image->widget);
 	$image->widget->signal_connect (
@@ -171,7 +136,7 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{image_zoom} = $image;
 	
-	$label = Gtk::Label->new (__"After zoom");
+	$label = Gtk::Label->new ("After Zoom");
 	$label->show;
 	$box->pack_start ($label, 0, 1, 0);
 	$label = Gtk::Label->new ("");
@@ -190,12 +155,11 @@ sub create_adjust_tab {
 	$box->pack_start ($frame, 0, 1, 0);
 	
 	$image = Video::DVDRip::GUI::ImageClip->new (
-		gtk_window    => $self->comp('main')->widget,
-		width         => 180,
-		height        => 160,
-		thumbnail     => $self->config('thumbnail_factor'),
-		no_clip       => 1,
-		show_tooltips => $self->config('show_tooltips'),
+		gtk_window => $self->comp('main')->widget,
+		width      => 180,
+		height     => 160,
+		thumbnail  => $self->config('thumbnail_factor'),
+		no_clip    => 1,
 	);
 	$frame->add ($image->widget);
 	$image->widget->signal_connect (
@@ -208,7 +172,7 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{image_clip2} = $image;
 	
-	$label = Gtk::Label->new (__"After 2nd clipping");
+	$label = Gtk::Label->new ("After 2nd Clipping");
 	$label->show;
 	$box->pack_start ($label, 0, 1, 0);
 	$label = Gtk::Label->new ("");
@@ -218,7 +182,7 @@ sub create_adjust_tab {
 
 	# Adjust Size and Clipping Parameters ------------------------------
 
-	$frame = Gtk::Frame->new (__"Adjust clip and zoom parameters");
+	$frame = Gtk::Frame->new ("Adjust Clip and Zoom Parameters");
 	$frame->show;
 	$vbox->pack_start ( $frame, 0, 1, 0);
 
@@ -228,17 +192,17 @@ sub create_adjust_tab {
 
 	$frame->add ($hbox);
 
-	my $table = Gtk::Table->new ( 5, 3, 0 );
+	my $table = Gtk::Table->new ( 4, 3, 0 );
 	$table->show;
 	$table->set_row_spacings ( 10 );
-	$table->set_col_spacings ( 5 );
-	$hbox->pack_start ($table, 1, 1, 0);
+	$table->set_col_spacings ( 10 );
+	$hbox->pack_start ($table, 0, 1, 0);
 
 	# Presets Menu
 	my $row = 0;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new (__"Presets");
+	$label = Gtk::Label->new ("Presets");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach_defaults ($hbox, 0, 1, $row, $row+1);
@@ -255,7 +219,6 @@ sub create_adjust_tab {
 			my ($widget, $name) = @_;
 			my $title = $self->selected_title;
 			return 1 if not $title;
-			return 1 if $self->in_adjust_init;
 			$title->set_preset ($name);
 		}, $preset->name);
 		$popup_menu->append($item);
@@ -265,24 +228,21 @@ sub create_adjust_tab {
 	$popup = Gtk::OptionMenu->new;
 	$popup->show;
 	$popup->set_menu($popup_menu);
-	$popup->set_usize(120,undef);
-
+	
 	$table->attach_defaults ($popup, 1, 2, $row, $row+1);
 
 	$self->adjust_widgets->{preset_popup}      = $popup;
 	$self->adjust_widgets->{preset_popup_menu} = $popup_menu;
 
-	$button = Gtk::Button->new_with_label (__"Apply preset values");
+	$button = Gtk::Button->new_with_label ("Apply Preset Values");
 	$button->show;
 	$button->signal_connect ("clicked", sub {
 		my $title = $self->selected_title;
 		return 1 if not $title;
-		return 1 if not $title->is_ripped;
 		my $preset = $self->config_object->get_preset (
 			name => $title->preset
 		);
 		return if not $preset;
-		$self->log (__x("Applied preset '{preset}'.", preset => $preset->title ));
 		$title->apply_preset ( preset => $preset );
 		$self->make_previews;
 		$self->init_adjust_values;
@@ -293,7 +253,7 @@ sub create_adjust_tab {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new (__"1st clipping");
+	$label = Gtk::Label->new ("1st Clipping");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach_defaults ($hbox, 0, 1, $row, $row+1);
@@ -302,15 +262,11 @@ sub create_adjust_tab {
 	$hbox->show;
 	$table->attach_defaults ($hbox, 1, 2, $row, $row+1);
 
-	$label = Gtk::Label->new(__"Top");
+	$label = Gtk::Label->new("Top");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -318,15 +274,11 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{tc_clip1_top}      = $entry;
 
-	$label = Gtk::Label->new(__"Bottom");
+	$label = Gtk::Label->new("Bottom");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -334,15 +286,11 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{tc_clip1_bottom}      = $entry;
 
-	$label = Gtk::Label->new(__"Left");
+	$label = Gtk::Label->new("Left");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -350,15 +298,11 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{tc_clip1_left}      = $entry;
 
-	$label = Gtk::Label->new(__"Right");
+	$label = Gtk::Label->new("Right");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -366,7 +310,7 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{tc_clip1_right}      = $entry;
 
-	$button = Gtk::Button->new_with_label (__"Generate preview images");
+	$button = Gtk::Button->new_with_label (" Generate Preview Images ");
 
 	$button->show;
 	$button->signal_connect ("clicked", sub {
@@ -379,7 +323,7 @@ sub create_adjust_tab {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new (__"Zoom");
+	$label = Gtk::Label->new ("Zoom");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach_defaults ($hbox, 0, 1, $row, $row+1);
@@ -388,15 +332,11 @@ sub create_adjust_tab {
 	$hbox->show;
 	$table->attach_defaults ($hbox, 1, 2, $row, $row+1);
 
-	$label = Gtk::Label->new(__"Width");
+	$label = Gtk::Label->new("Width");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 0,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -404,15 +344,11 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{tc_zoom_width}      = $entry;
 
-	$label = Gtk::Label->new(__"Height");
+	$label = Gtk::Label->new("Height");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 0,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -420,84 +356,11 @@ sub create_adjust_tab {
 
 	$self->adjust_widgets->{tc_zoom_height}      = $entry;
 
-	$label = Gtk::Label->new ("");
-	$label->show;
-	$hbox->pack_start($label, 0, 1, 0);
-
-	$self->adjust_widgets->{tc_zoom_info}        = $label;
-
-	$hbox = Gtk::HBox->new;
-	$hbox->show;
-	
-	$table->attach_defaults ($hbox, 2, 3, $row, $row+1);
-
-	$button = Gtk::Button->new_with_label (__"Calc height");
-	$button->show;
-	$button->signal_connect ("clicked", sub {
-		$self->calc_zoom ( height => 1 );
-	});
-	$hbox->pack_start ($button, 0, 1, 0);
-	
-	$button = Gtk::Button->new_with_label (__"Calc width");
-	$button->show;
-	$button->signal_connect ("clicked", sub {
-		$self->calc_zoom ( width => 1 );
-	});
-	$hbox->pack_start ($button, 0, 1, 0);
-	
-	# fast resizing
-	++$row;
-	$hbox = Gtk::HBox->new;
-	$hbox->show;
-	$label = Gtk::Label->new (__"Use fast resizing");
-	$label->show;
-	$hbox->pack_start($label, 0, 1, 0);
-	$table->attach_defaults ($hbox, 0, 1, $row, $row+1);
-	
-	$hbox = Gtk::HBox->new;
-	$hbox->show;
-	my $radio_yes = Gtk::RadioButton->new (__"Yes");
-	$radio_yes->show;
-	$hbox->pack_start($radio_yes, 0, 1, 0);
-	my $radio_no = Gtk::RadioButton->new (__"No", $radio_yes);
-	$radio_no->show;
-	$hbox->pack_start($radio_no, 0, 1, 0);
-	$table->attach_defaults ($hbox, 1, 2, $row, $row+1);
-
-	$self->adjust_widgets->{tc_fast_resize_yes} = $radio_yes;
-	$self->adjust_widgets->{tc_fast_resize_no}  = $radio_no;
-
-	# fast bisection
-
-if ( 0 ) {
-	$label = Gtk::Label->new (__"Fast frame bisection");
-	$label->show;
-	$hbox->pack_start($label, 0, 1, 0);
-
-	$radio_yes = Gtk::RadioButton->new (__"Yes");
-	$radio_yes->show;
-	$hbox->pack_start($radio_yes, 0, 1, 0);
-	$radio_no = Gtk::RadioButton->new (__"No", $radio_yes);
-	$radio_no->show;
-	$hbox->pack_start($radio_no, 0, 1, 0);
-
-	$self->adjust_widgets->{tc_fast_bisection_yes} = $radio_yes;
-	$self->adjust_widgets->{tc_fast_bisection_no}  = $radio_no;
-}
-
-	$button = Gtk::Button->new_with_label (__"Open zoom calculator");
-
-	$button->show;
-	$button->signal_connect ("clicked", sub {
-		$self->zoom_calculator;
-	});
-	$table->attach_defaults ($button, 2, 3, $row, $row+1);
-
 	# Clipping #2
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new (__"2nd clipping");
+	$label = Gtk::Label->new ("2nd Clipping");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach_defaults ($hbox, 0, 1, $row, $row+1);
@@ -506,15 +369,11 @@ if ( 0 ) {
 	$hbox->show;
 	$table->attach_defaults ($hbox, 1, 2, $row, $row+1);
 
-	$label = Gtk::Label->new(__"Top");
+	$label = Gtk::Label->new("Top");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -522,15 +381,11 @@ if ( 0 ) {
 
 	$self->adjust_widgets->{tc_clip2_top}      = $entry;
 
-	$label = Gtk::Label->new(__"Bottom");
+	$label = Gtk::Label->new("Bottom");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -538,15 +393,11 @@ if ( 0 ) {
 
 	$self->adjust_widgets->{tc_clip2_bottom}   = $entry;
 
-	$label = Gtk::Label->new(__"Left");
+	$label = Gtk::Label->new("Left");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -554,15 +405,11 @@ if ( 0 ) {
 
 	$self->adjust_widgets->{tc_clip2_left}     = $entry;
 
-	$label = Gtk::Label->new(__"Right");
+	$label = Gtk::Label->new("Right");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 
-	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number	=> 1,
-		may_empty	=> 1,
-		may_negative	=> 1,
-	);
+	$entry = Gtk::Entry->new;
 	$entry->set_text ("");
 	$entry->set_usize(40, undef);
 	$entry->show;
@@ -570,7 +417,7 @@ if ( 0 ) {
 
 	$self->adjust_widgets->{tc_clip2_right}      = $entry;
 
-	$button = Gtk::Button->new_with_label (__"Move 2nd clipping to 1st");
+	$button = Gtk::Button->new_with_label (" Move 2nd Clipping to 1st ");
 
 	$button->show;
 	$button->signal_connect ("clicked", sub {
@@ -587,55 +434,22 @@ if ( 0 ) {
        			       tc_clip2_top  tc_clip2_bottom
 			       tc_clip2_left tc_clip2_right )) {
 		$widgets->{$attr}->signal_connect ("changed", sub {
-			my $title = $self->selected_title;
-			return 1 if not $title;
-			$self->update_storage_labels
-				if $attr ne 'preview_frame_nr' &&
-				   $title->tc_video_bitrate_manual;
-			return 1 if $self->in_adjust_init;
 			my ($widget, $method) = @_;
-			$title->$method ( $widget->get_text );
-			$self->update_fast_resize_info;
-			$self->show_preview_labels;
-			1;
+			$self->selected_title->$method ( $widget->get_text );
 		}, "set_$attr");
 	}
 
-	$self->adjust_widgets->{tc_fast_resize_yes}->signal_connect (
-		"clicked", sub {
-			return 1 if not $self->selected_title;
-			return 1 if $self->in_adjust_init;
-			$self->selected_title->set_tc_fast_resize(1);
-			$self->show_preview_labels ( type => "zoom" );
-			1;
-		}
-	);
-	$self->adjust_widgets->{tc_fast_resize_no}->signal_connect (
-		"clicked", sub {
-			return 1 if not $self->selected_title;
-			return 1 if $self->in_adjust_init;
-			$self->selected_title->set_tc_fast_resize(0);
-			$self->show_preview_labels ( type => "zoom" );
-		}
-	);
-
 	return $vbox;
 }
 
 sub init_adjust_values {
 	my $self = shift; $self->trace_in;
-	my %par = @_;
-	my ($no_preview_update) = @par{'no_preview_update'};
 
 	my $title = $self->selected_title;
 	return 1 if not $title;
+	return 1 if not $self->adjust_widgets->{preview_frame_nr};
 
-	$self->set_in_adjust_init(1);
-
-	$self->show_preview_images if not $no_preview_update;
-
-	my $fast_resize    = $title->tc_fast_resize;
-	my $fast_bisection = $title->tc_fast_bisection;
+	$self->show_preview_images;
 
 	my $widgets = $self->adjust_widgets;
 	foreach my $attr (qw ( preview_frame_nr
@@ -644,7 +458,7 @@ sub init_adjust_values {
 			       tc_clip1_left tc_clip1_right
        			       tc_clip2_top  tc_clip2_bottom
 			       tc_clip2_left tc_clip2_right )) {
-		$widgets->{$attr}->set_text ($self->selected_title->$attr());
+		$widgets->{$attr}->set_text ($self->selected_title->$attr);
 	}
 
 	my $preset_name = $title->preset;
@@ -656,63 +470,6 @@ sub init_adjust_values {
 	$i = 0 if $i >= @{$self->config_object->presets};
 	$widgets->{preset_popup}->set_history ($i);
 
-	$widgets->{preview_frame_nr}->set_is_max ( $title->frames );
-
-	$widgets->{tc_fast_resize_yes}->set_active($fast_resize);
-	$widgets->{tc_fast_resize_no}->set_active(!$fast_resize);
-
-	$widgets->{force_slow_grabbing}->set_active($title->tc_force_slow_grabbing);
-
-	$self->update_fast_resize_info;
-
-	$self->set_in_adjust_init(0);
-
-	1;
-}
-
-sub update_fast_resize_info {
-	my $self = shift; $self->trace_in;
-
-	my $title = $self->selected_title;
-	return 1 if not $title;
-	return 1 if not $self->adjust_widgets->{preview_frame_nr};
-
-	my $info = "";
-	my $style = $self->text_norm_style;
-	if ( $title->tc_fast_resize ) {
-		my ($width_n, $height_n, $err_div32, $err_shrink_expand) =
-			$title->get_fast_resize_options;
-
-		if ( $err_div32 or $err_shrink_expand ) {
-			my $multiple_of = 8;
-			$info .= "$multiple_of boundary! " if $err_div32;
-			$info .= "shrink-expand!" if $err_shrink_expand;
-			$info =~ s! $!!;
-			$info =~ s! s! / s!;
-			$info = "Err: $info";
-			if ( $err_shrink_expand ) {
-				$self->adjust_widgets->{"zoom_info_label"}->set_style ($self->text_warn_style);
-				$self->adjust_widgets->{"clip1_info_label"}->set_style ($self->text_warn_style);
-			}
-			$self->adjust_widgets->{"zoom_info_label"}->set_style ($self->text_warn_style)
-				if $title->tc_zoom_width % 8 or $title->tc_zoom_height % 8;
-			$self->adjust_widgets->{"clip1_info_label"}->set_style ($self->text_warn_style)
-				if $title->tc_clip1_left % 8 or $title->tc_clip1_right % 8 or
-				   $title->tc_clip1_top % 8 or $title->tc_clip1_bottom;
-
-			$style = $self->text_warn_style;
-		} else {
-			$info = "Fast resize: Ok";
-			$self->adjust_widgets->{"zoom_info_label"}->set_style ($self->text_norm_style);
-			$self->adjust_widgets->{"clip1_info_label"}->set_style ($self->text_norm_style);
-		}
-	} else {
-		$self->adjust_widgets->{"clip1_info_label"}->set_style ($self->text_norm_style);
-	}
-
-	$self->adjust_widgets->{tc_zoom_info}->set_text  ($info);
-	$self->adjust_widgets->{tc_zoom_info}->set_style ($style);
-
 	1;
 }
 
@@ -770,44 +527,24 @@ sub show_preview_labels {
 		@types = qw ( clip1 zoom clip2 );
 	}
 
-	my ($width, $height, $warn_width, $warn_height, $text, $ratio, $phys_ratio);
+	my ($width, $height, $warn_width, $warn_height, $text, $ratio);
 	foreach $type ( @types ) {
-		($width, $height, $ratio) = $title->get_effective_ratio ( type => $type );
-		$ratio   = "4:3"  if $ratio >= 1.32 and $ratio <= 1.34;
-		$ratio   = "16:9" if $ratio >= 1.76 and $ratio <= 1.78;
-		($ratio) = $ratio =~ /(\d+\.\d{1,2})/ if $ratio !~ /:/;
-		$phys_ratio = $width/$height;
-		($phys_ratio) = $phys_ratio =~ /(\d+\.\d{1,2})/;
-		$warn_width  = ($type eq 'clip2' and $width  % 16) ? "!":"";
-		$warn_height = ($type eq 'clip2' and $height % 16) ? "!":"";
-		$warn_width  ||= ($width  % 2) ? "!":"";
-		$warn_height ||= ($height % 2) ? "!":"";
-		if ( $type eq 'clip1' ) {
-			$warn_height  ||= "!" if $title->tc_clip1_top %2 or
-						 $title->tc_clip1_bottom %2;
-			$warn_width   ||= "!" if $title->tc_clip1_left %2 or
-						 $title->tc_clip1_right %2;
-		}
-		if ( $type eq 'clip2' ) {
-			$warn_height  ||= "!" if $title->tc_clip2_top %2 or
-						 $title->tc_clip2_bottom %2;
-			$warn_width   ||= "!" if $title->tc_clip2_left %2 or
-						 $title->tc_clip2_right %2;
-		}
-		$text = sprintf (__"Size: %d%sx%d%s\nEff. ratio: %s, phys. ratio: %s",
+		$image = $self->adjust_widgets->{"image_$type"};
+		$width  = $image->image_width;
+		$height = $image->image_height;
+		next if $width == 0 or $height == 0;
+		$ratio  = sprintf ("%2.2f", ($width/$height));
+		$ratio  = "4:3" if $ratio eq '1.33';
+		$ratio  = "16:9" if $ratio eq '1.77';
+		$warn_width = ($width%8) ? "!":"";
+		$warn_height = ($height%8) ? "!":"";
+		$text = sprintf ("Size: %d%sx%d%s, Ratio: %s",
 			$width, $warn_width, $height, $warn_height,
-			$ratio, $phys_ratio
+			$ratio
 		);
-
+		
 		$self->adjust_widgets->{$type."_info_label"}->set_text($text);
-		if ( $warn_width or $warn_height ) {
-			$self->adjust_widgets->{$type."_info_label"}->set_style ($self->text_warn_style);
-		} else {
-			$self->adjust_widgets->{$type."_info_label"}->set_style ($self->text_norm_style);
-		}
 	}
-
-	$self->update_fast_resize_info;
 	
 	1;
 }
@@ -824,88 +561,46 @@ sub grab_preview_frame {
 
 	return 1 if not defined $frame_nr;
 
-	if ( not $title->is_ripped ) {
+	if ( not $title->rip_time ) {
 		$self->message_window (
-			message => __"You first have to rip this title."
-		);
-		return 1;
-	}
-
-	my $nr;
-	my $last_job;
-
-	my $job = Video::DVDRip::Job::GrabPreviewFrame->new (
-		nr    => ++$nr,
-		title => $title,
-	);
-
-	my $exec;
-	$exec = Video::DVDRip::GUI::ExecuteJobs->new (
-		cb_finished => sub {
-			return 1 if not $job->operation_successful;
-			return 1 if $exec->cancelled;
-			$title->apply_preset ( 
-				preset => $self->config_object->get_preset (
-					name => $title->preset
-				)
-			) if not $title->last_applied_preset;
-
-			$self->make_previews;
-			$self->show_preview_images;
-			$self->init_adjust_values;
-			
-			1;
-		}
-	);
-
-	$last_job = $exec->add_job ( job => $job );
-
-	$exec->execute_jobs;
-
-	1;
-}
-
-sub preview_video {
-	my $self = shift; $self->trace_in;
-
-	my $title = $self->selected_title;
-	return 1 if not $title;
-	
-	my $frame_nr = $title->preview_frame_nr;
-	my $filename = $title->preview_filename( type => 'orig' );
-
-	return 1 if not defined $frame_nr;
-
-	if ( not $title->is_ripped ) {
-		$self->message_window (
-			message => __"You first have to rip this title."
-		);
-		return 1;
-	}
-
-	if ( $title->project->rip_mode ne 'rip' ) {
-		$self->message_window (
-			message => __"This function is only available for ripped DVD's."
+			message => "You first have to rip this title."
 		);
 		return 1;
 	}
 
 	if ( $frame_nr > $title->frames or $frame_nr !~ /^\d+/ ) {
 		$self->message_window (
-			message => __"Illegal frame number. Maximum is ".
+			message => "Illegal frame number. Maximum is ".
 				   ($title->frames-1)
 		);
 		return 1;
 	}
 
-	my $command = $title->get_view_stdin_command (
-		command_tmpl => $self->config('play_stdin_command'),
+	my $fh = $title->take_snapshot_async_start (
+		frame    => $frame_nr,
+		filename => $filename,
 	);
 
-	$self->log (__x("Executing command for video preview: {command}", command => $command));
-
-	system ("$command &");
-
+	$self->comp('progress')->open_continious_progress (
+		max_value => $frame_nr,
+		label     => "Grabbing Preview Image",
+		fh        => $fh,
+		get_progress_callback => sub {
+			my %par = @_;
+			my ($buffer) = @par{'buffer'};
+			$buffer =~ /\[0+-(\d+)\].*?$/;
+			return $1;
+		},
+		finished_callback => sub {
+			$title->take_snapshot_async_stop ( fh => $fh );
+			$self->make_previews;
+			$self->show_preview_images;
+		},
+		cancel_callback => sub {
+			close $fh;
+		},
+	);
+	
 	1;
 }
 
@@ -930,7 +625,7 @@ sub open_preview_window {
 	return 1 if defined $self->adjust_widgets->{"window_$type"};
 	my $title = $self->selected_title;
 	return 1 if not $title;
-	
+
 	my $file_type;
 	$file_type = 'orig' if $type eq 'clip1';
 	$file_type = 'zoom' if $type eq 'zoom';
@@ -940,12 +635,13 @@ sub open_preview_window {
 	return 1 if not -f $filename;
 
 	my $win = Gtk::Window->new;
+	$win->set_uposition (10,10);
 	$win->signal_connect( 'destroy', sub {
 		$self->adjust_widgets->{"window_$type"} = undef;
 		$self->make_previews if $type ne 'zoom';
 		$self->show_preview_images;
 	} );
-	$win->set_title (__x("Adjust {type}", type => $type));
+	$win->set_title ("Adjust $type");
 	$win->show;
 	
 	my $vbox = Gtk::VBox->new;
@@ -970,21 +666,13 @@ sub open_preview_window {
 			     ->set_text ($value);
 
 			if ( $clip_type =~ /left/ or $clip_type =~ /right/ ) {
-				my $width = $self->adjust_widgets
-						 ->{"image_$type"}
-						 ->image_width;
+				my $width = $self->adjust_widgets->{"image_$type"}->image_width;
 				$width -= $value-$old_value;
-				$self->adjust_widgets
-				     ->{"image_$type"}
-				     ->set_image_width($width);
+				$self->adjust_widgets->{"image_$type"}->set_image_width($width);
 			} else {
-				my $height = $self->adjust_widgets
-						  ->{"image_$type"}
-						  ->image_height;
+				my $height = $self->adjust_widgets->{"image_$type"}->image_height;
 				$height -= $value-$old_value;
-				$self->adjust_widgets
-				     ->{"image_$type"}
-				     ->set_image_height($height);
+				$self->adjust_widgets->{"image_$type"}->set_image_height($height);
 			}
 			$self->show_preview_labels ( type => $type );
 		},
@@ -1019,20 +707,6 @@ sub move_clip2_to_clip1 {
 	my $title = $self->selected_title;
 	return 1 if not $title;
 
-	if ( not $title->is_ripped ) {
-		$self->message_window (
-			message => __"You first have to rip this title."
-		);
-		return 1;
-	}
-
-	if ( $title->tc_fast_resize ) {
-		$self->message_window (
-			message => __"This is not possible because\nfast resizing is enabled."
-		);
-		return 1;
-	}
-
 	my $clip1_top    = $title->tc_clip1_top;
 	my $clip1_bottom = $title->tc_clip1_bottom;
 	my $clip1_left   = $title->tc_clip1_left;
@@ -1040,8 +714,9 @@ sub move_clip2_to_clip1 {
 
 	if ( $clip1_top or $clip1_bottom or $clip1_left or $clip1_right ) {
 		$self->message_window (
-			message =>
-				__"2nd clipping parameters can only be\nmoved to 1st clipping parameters, if\n1st clipping is not defined."
+			message => "2nd clipping parameters can only moved\n".
+				   "to 1st clipping parameters, if 1st clipping\n".
+				   "is not defined."
 		);
 		return 1;
 	}
@@ -1049,8 +724,8 @@ sub move_clip2_to_clip1 {
 	my $width        = $title->width;
 	my $height       = $title->height;
 	
-	my $zoom_width   = $title->tc_zoom_width  || $title->width;
-	my $zoom_height  = $title->tc_zoom_height || $title->height;
+	my $zoom_width   = $title->tc_zoom_width;
+	my $zoom_height  = $title->tc_zoom_height;
 	
 	my $x_factor = $zoom_width/$width;
 	my $y_factor = $zoom_height/$height;
@@ -1071,33 +746,6 @@ sub move_clip2_to_clip1 {
 	$zoom_width  = $width  * $x_factor;
 	$zoom_height = $height * $y_factor;
 	
-	# no odd clip values
-	if ( $clip1_left % 2 and $clip1_right %2 ) {
-		if ( $clip1_left > $clip1_right ) {
-			--$clip1_left;
-			++$clip1_right;
-		} else {
-			++$clip1_left;
-			--$clip1_right;
-		}
-	} else {
-		--$clip1_left  if $clip1_left  % 2;
-		--$clip1_right if $clip1_right % 2;
-	}
-
-	if ( $clip1_top % 2 and $clip1_bottom %2 ) {
-		if ( $clip1_left > $clip1_bottom ) {
-			--$clip1_top;
-			++$clip1_bottom;
-		} else {
-			++$clip1_top;
-			--$clip1_bottom;
-		}
-	} else {
-		--$clip1_top    if $clip1_top    % 2;
-		--$clip1_bottom if $clip1_bottom % 2;
-	}
-
 	$title->set_tc_clip1_top    (int($clip1_top));
 	$title->set_tc_clip1_bottom (int($clip1_bottom));
 	$title->set_tc_clip1_left   (int($clip1_left));
@@ -1115,49 +763,4 @@ sub move_clip2_to_clip1 {
 	1;
 }
 
-sub calc_zoom {
-	my $self = shift;
-	my %par = @_;
-	my ($width, $height) = @par{'width','height'};
-	
-	my $title = $self->selected_title;
-	return 1 if not $title;
-
-	if ( not $title->is_ripped ) {
-		$self->message_window (
-			message => __"You first have to rip this title."
-		);
-		return 1;
-	}
-
-	$title->calc_zoom (
-		width  => $width,
-		height => $height,
-	);
-
-	$self->make_previews;
-	$self->init_adjust_values;
-
-	1;
-}
-
-sub zoom_calculator {
-	my $self = shift;
-	
-	my $title = $self->selected_title;
-	return 1 if not $title;
-
-	if ( not $title->is_ripped ) {
-		$self->message_window (
-			message => __"You first have to rip this title."
-		);
-		return 1;
-	}
-
-	my $calculator = Video::DVDRip::GUI::ZoomCalculator->new;
-	$calculator->open_window;
-
-	1;	
-}
-
 1;
